@@ -29,6 +29,7 @@
 import sys
 import datetime
 import os
+import traceback
 from functools import wraps
 import time
 
@@ -67,4 +68,12 @@ def conlog(*args):
     text = ''
     for tx in args:
         text += f"{tx} "
-    print(f'\033[1;31m {date} \033[0m - \033[4;33m{os.path.basename(__file__)}\033[0m -\033[1;35m 位置:{sys._getframe().f_lineno}\033[0m - \033[0;32m{text}\033[0m')
+    trc = traceback.extract_stack()[-2]
+    print(f'\033[1;31m {date} \033[0m - \033[4;33m{trc.filename}\033[0m -\033[1;32m {trc.name}|{trc.lineno}\033[0m - {text}')
+
+
+def tt():
+    conlog(90)
+
+if __name__ == '__main__':
+  tt()
